@@ -45,7 +45,7 @@ def list_alerts(compliance_standard, amount, unit, status, detailed, policy_id,
     # Add a new column with a url to the alert investigate page
     url = "https://app.eu.prismacloud.io/investigate/details?resourceId="
     for alert in alerts:
-        alert["alert.resource.url"] = f"{url} + {alert['resource']['rrn']}"
+        alert["alert.resource.url"] = f"{url}{alert['resource']['rrn']}"
 
     # We want to get the related policy information so fetch the policies
     policies = pc_api.policy_list_read()
